from promptmodel import FunctionModel, UnitLogger, init
from datetime import datetime

init(use_cache=False)

async def test():
    current_time = datetime.now()
    
    
    unit: UnitLogger = await UnitLogger("test_unit", 1).log_start()
    res = await FunctionModel("summarize", unit_config=unit.config).arun({"text": "hello, world!"})
    await FunctionModel("summarize").log_score(res.pm_detail.log_uuid, {"accuracy" : 3})
    await unit.log_score({"user_submit" : 1})
    
    
    print("Time Usage: ", datetime.now() - current_time)
    
    current_time = datetime.now()
    res = await FunctionModel("summarize", unit_config=unit.config).arun({"text": "hello, world!"})
    print("Time Usage: ", datetime.now() - current_time)
    
    
    # unit: UnitLogger = UnitLogger("test_unit", 1).log_start()
    # summarize = FunctionModel("summarize", unit_config=unit.config)
    # res = await summarize.arun({"text": "hello, world!"})
    # summarize.log_score({"accuracy" : 3})
    # unit.log_score({"user_submit" : 1})
    

async def test_2():
    unit: UnitLogger = await UnitLogger("test_unit", 2).log_start()
    res = await FunctionModel("summarize", unit_config=unit.config).arun({"text": "hello, world!"})
    print(res.raw_output)
    print(res.pm_detail.log_uuid)
    await unit.log_score({"user_submit" : 1})

if __name__ == "__main__":
    import asyncio
    asyncio.run(test())
    # asyncio.run(test_2())
    
    



from .dev_app import DevClient, DevApp
from .function_model import FunctionModel, PromptModel
from .chat_model import ChatModel
from .promptmodel_init import init
from .unit_logger import UnitLogger

__version__ = "0.1.15"




from typing import (
    Dict,
    Optional,
)

import promptmodel.utils.logger as logger
from promptmodel.utils.async_utils import run_async_in_sync
from promptmodel.utils.config_utils import check_connection_status_decorator
from promptmodel.types.response import (
    UnitConfig,
)
from promptmodel.apis.base import AsyncAPIClient

class UnitLogger:
    def __init__(
        self,
        name: str,
        version: int
    ):
        self.name: str = name
        self.version: int = version
        self.config: Optional[UnitConfig] = None
        
    @check_connection_status_decorator
    def get_config(self) -> Optional[UnitConfig]:
        """Get the config of the component
        You can get the config directly from the UnitLogger.confg attribute.
        """
        return self.config
    
    @check_connection_status_decorator
    async def log_start(self, *args, **kwargs) -> Optional["UnitLogger"]:
        """Create Component Log on the cloud.
        It returns the UnitLogger itself, so you can use it like this:
        >>> component = UnitLogger("intent_classification_unit", 1).log_start()
        >>> res = FunctionModel("intent_classifier", unit_config=component.config).run(...)
        >>> component.log_score({"accuracy": 0.9})
        """
        res = await AsyncAPIClient.execute(
            method="POST",
            path="/unit/log",
            json={
                "name": self.name,
                "version": self.version,
            },
            use_cli_key=False
        )
        if res.status_code != 200:
            logger.error(f"Failed to log start for component {self.name} v{self.version}")
            return None
        else:
            self.config = UnitConfig(**res.json())
            
        return self
        
    
    @check_connection_status_decorator
    async def log_score(self, scores: Dict[str, float], *args, **kwargs):
        res = await AsyncAPIClient.execute(
            method="POST",
            path="/unit/score",
            json={
                "unit_log_uuid" : self.config.log_uuid,
                "scores": scores,
            },
            use_cli_key=False
        )
        if res.status_code != 200:
            logger.error(f"Failed to log score for component {self.name} v{self.version}")
            
        return
    


from promptmodel import FunctionModel, init

init(use_cache=False, mask_inputs=False)

async def test():
    api_res = None
    stream_res = await FunctionModel("ENG").astream()
    async for res in stream_res:
        print(res.api_response)
        api_res = res.api_response
    
    print(api_res)
    print(api_res._response_ms)

if __name__ == "__main__":
    import asyncio
    asyncio.run(test())
